read_xlsb: Loads a XLSB file

Description Usage Arguments Value Examples

Description

This is the basic function of the package, wich reads the xlsb files as a database using RODBC.

Usage

1

Arguments

x

A filename or filepath.

Value

A dataframe containing data stored in the file.

Examples

1
2
DT <- read_xlsb("data/march.xlsb")
DT <- read_xlsb("march.xlsb")

gabrielrega/xlsb documentation built on May 13, 2019, 8:38 a.m.