Description Usage Arguments Value Examples
This is the basic function of the package, wich reads the xlsb files as a database using RODBC.
1 | read_xlsb(x)
|
x |
A filename or filepath. |
A dataframe containing data stored in the file.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.